@@ -23,7 +23,7 @@ with 'MooseX::SimpleConfig';
 # For pretty man pages!
 $ENV{TERM} = 'xterm-256color';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =encoding utf-8
 
@@ -311,7 +311,7 @@ has 'template_file' => (
 #SBATCH --mem=[% self.mem %]
 [% END %]
 [% IF self.has_walltime %]
-#SBATCH --walltime=[% self.walltime %]
+#SBATCH --time=[% self.walltime %]
 [% END %]
 [% IF AFTEROK %]
 #SBATCH --dependency=afterok:[% AFTEROK %]
@@ -1113,9 +1113,9 @@ sub process_batch_command {
             . " --outdir "
             . $self->outdir
             . " --logname $counter" . "_"
+            . $self->jobname
             . " --process_table "
-            . $self->process_table
-            . $self->jobname;
+            . $self->process_table;
     }
     else {
         die print "None of the job processes were chosen!\n";
